AITypeEnum - agents API reference (0.0.10)

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# AITypeEnum

class inmydata.ConversationalData.AITypeEnum(value)

  Bases: `Enum`

  Enum representing the different platform options used to respond to the question.

  azureopenai

    Microsoft Azure OpenAI service.

  openai

    OpenAI’s own API service.

  azureopenai = 0
  openai = 1